@@ -30,7 +30,7 @@ pub fn solve(input: &mut Input) -> Result<Word, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_one_error, test_part_two};
+    use crate::input::{test_part_one, test_part_one_error, test_part_two};
 
     let solution = include_str!("day02_input.txt");
     test_part_one!(solution => 4_570_637);
